
/* 
 * File: "CoxeterExtensions_by_EM_InvolBruhatIterator.cpp"
 *
 * Author: Eric Marberg
 * Version: June 2013
 * --------------------------------------------------------------
 * Source file for "CoxeterExtensions_by_EM_InvolBruhatIterator.h"
 *
 */



#include "CoxeterExtensions_by_EM_InvolBruhatIterator.h"



/*
 * Function: InvolBruhatIterator constructor
 * ---------------------------------------------------------
 * See the class description in "CoxeterExtensions_by_EM_InvolBruhatIterator.h" 
 * for an explanation of the arguments in this constructor.
 *
 */
InvolBruhatIterator::InvolBruhatIterator(std::vector<int>** bruhat_ascents_in, int y_index, int w_index_in)
{
	bruhat_ascents = bruhat_ascents_in;
	
	w_index = w_index_in;
	
	current.insert(y_index);
	it = current.begin();
}




/*
 * Function: next
 * ---------------------------------------------------------
 * Returns the index of the twisted involution which is next
 * in the order constructed by the InvolBruhatIterator
 *
 */
int InvolBruhatIterator::next()
{
	// index to be returned
	int z_index = *it;
	
	// adds all indices which cover z_index to our next pool
	std::vector<int> vec = bruhat_ascents[w_index][z_index];
	for(int i=0; i<vec.size(); i++) following.insert(vec[i]);
	
	// advance current pool's iterator forward
	++it;
	
	// if at end of current pool, swap current and next pools
	// and assign it accordingly
	if(it == current.end())
	{
		current = following;
		it = current.begin();
		following.clear();
	}
	
	return z_index;
}



